==> stopwatch-home_0.2.tar.gz: stopwatch-home-0.2/src/main.cpp <==
/****************************************************************************
** Simple Timer Widget
** Author: Ilkka Salminen <ilkkas@gmail.com>, 2009
** Design: Jaakko Roppola
** Build on top of Antonio Alonso's example how to make desktop widgets with Qt.
**
****************************************************************************/
#include "widget.h"

#include <QApplication>

#include <X11/extensions/Xrender.h>

int main(int argc, char **argv)
{
    //qWarning("Please make sure you're running a composition manager!");
    bool  argbVisual=false;
    Display *dpy = XOpenDisplay(0); // open default display
    if (!dpy) {
        qWarning("Cannot connect to the X server");
        exit(1);
    }

    int screen = DefaultScreen(dpy);
    Colormap colormap = 0;
    Visual *visual = 0;
    int eventBase, errorBase;

    if (XRenderQueryExtension(dpy, &eventBase, &errorBase)) {
        int nvi;
        XVisualInfo templ;
        templ.screen  = screen;
        templ.depth   = 32;
        templ.c_class = TrueColor;
        XVisualInfo *xvi = XGetVisualInfo(dpy, VisualScreenMask |
                                          VisualDepthMask |
                                          VisualClassMask, &templ, &nvi);
    
        for (int i = 0; i < nvi; ++i) {
            XRenderPictFormat *format = XRenderFindVisualFormat(dpy,
                                                                xvi[i].visual);
            if (format->type == PictTypeDirect && format->direct.alphaMask) {
                visual = xvi[i].visual;
                colormap = XCreateColormap(dpy, RootWindow(dpy, screen),
                                           visual, AllocNone);
                argbVisual=true;
                break;
            }
        }
    }
    if (argbVisual == true) {
        qWarning("Found ARGB visual. Starting app...");
    }
    else  {
        qWarning("Couldn't find ARGB visual... Exiting.");
        exit(1);
    }


    QApplication app(dpy, argc, argv,
                     Qt::HANDLE(visual), Qt::HANDLE(colormap));

    QCoreApplication::setOrganizationName("");
    QCoreApplication::setOrganizationDomain("");
    QCoreApplication::setApplicationName("StopWatch");

    Widget w;
    w.resize(250, 125);
    w.show();

    return app.exec();
}

==> stopwatch-home_0.3.tar.gz: stopwatch-home-0.3/src/main.cpp <==
/****************************************************************************
** Simple Timer Widget
** Author: Ilkka Salminen <ilkkas@gmail.com>, 2009
** Design: Jaakko Roppola
** Build on top of Antonio Alonso's example how to make desktop widgets with Qt.
**
****************************************************************************/
#include "widget.h"

#include <QApplication>
#include <QMessageBox>

#include <X11/extensions/Xrender.h>

int main(int argc, char **argv)
{
    //qWarning("Please make sure you're running a composition manager!");
    bool  argbVisual=false;
    Display *dpy = XOpenDisplay(0); // open default display
    if (!dpy) {
        qWarning("Cannot connect to the X server");
        exit(1);
    }

    int screen = DefaultScreen(dpy);
    Colormap colormap = 0;
    Visual *visual = 0;
    int eventBase, errorBase;

    if (XRenderQueryExtension(dpy, &eventBase, &errorBase)) {
        int nvi;
        XVisualInfo templ;
        templ.screen  = screen;
        templ.depth   = 32;
        templ.c_class = TrueColor;
        XVisualInfo *xvi = XGetVisualInfo(dpy, VisualScreenMask |
                                          VisualDepthMask |
                                          VisualClassMask, &templ, &nvi);
    
        for (int i = 0; i < nvi; ++i) {
            XRenderPictFormat *format = XRenderFindVisualFormat(dpy,
                                                                xvi[i].visual);
            if (format->type == PictTypeDirect && format->direct.alphaMask) {
                visual = xvi[i].visual;
                colormap = XCreateColormap(dpy, RootWindow(dpy, screen),
                                           visual, AllocNone);
                argbVisual=true;
                break;
            }
        }
    }
    if (argbVisual == true) {
        qWarning("Found ARGB visual. Starting app...");
    }
    else  {
        qWarning("Couldn't find ARGB visual... Exiting.");
        exit(1);
    }


    QApplication app(dpy, argc, argv,
                     Qt::HANDLE(visual), Qt::HANDLE(colormap));

    QCoreApplication::setOrganizationName("");
    QCoreApplication::setOrganizationDomain("");
    QCoreApplication::setApplicationName("StopWatch");

    Widget w;
    w.resize(250, 125);
    w.show();

    /* QMessageBox msgBox;
    msgBox.setText("Now look on your desktop for the stopwatch.");
    msgBox.exec(); */

    return app.exec();
}
